@@ -1,7 +1,8 @@
 import sys
-from typing import Any, Iterable, Mapping, Optional, Sequence, Union
+from typing import Any, Iterable, Mapping, Optional, Sequence, Tuple, Union
 
 from pychoir.core import Matchable, Matcher, Transformer
+from pychoir.utils import i_removed
 
 if sys.version_info >= (3, 8):
     from typing import Protocol
@@ -230,17 +231,21 @@ class DictContainsAllOf(Matcher):
 class InAnyOrder(Matcher):
     """A Matcher checking that an Iterable contains *exactly* the passed items, in any order.
 
-    The Iterable can be for example a list, tuple or set. Items do not need to be hashable.
+    The Iterable can be for example a list, tuple or set. Items can be Matchers and do not need to be hashable.
 
     :param values: An Iterable containing the expected items, in any order.
 
     Usage:
-      >>> from pychoir import InAnyOrder
+      >>> from pychoir import InAnyOrder, IsEven, IsOdd
       >>> [1, 2, 3, 3] == InAnyOrder([3, 2, 3, 1])
       True
-      >>> [1, 2] == InAnyOrder([3, 2, 1])
+      >>> [1, 2, 3] == InAnyOrder([3, 3, 2, 1])  # missing one 3
       False
-      >>> [{'a': 1}, {'b': 2}] == InAnyOrder([{'b': 2}, {'a': 1}])
+      >>> [1, 2, 3, 3] == InAnyOrder([3, 2, 1])  # one 3 too many
+      False
+      >>> [1, 2, 3] == InAnyOrder((1, 2, 3))  # type of the Iterable does not matter
+      True
+      >>> [{'a': 1}, {'b': 2}] == InAnyOrder([{'b': IsEven()}, {'a': IsOdd()}])
       True
     """
     def __init__(self, values: Iterable[Matchable]):
@@ -248,13 +253,18 @@ class InAnyOrder(Matcher):
         self.expected_values = values
 
     def _matches(self, other: Iterable[Any]) -> bool:
-        values_left = [value for value in self.expected_values]
-        for value in other:
-            try:
-                values_left.remove(value)
-            except ValueError:
-                return False
-        return not values_left
+        return self.__has_a_solution(tuple(self.expected_values), tuple(other))
+
+    def __has_a_solution(self, expected_left: Tuple[Matchable, ...], values_left: Tuple[Any, ...]) -> bool:
+        if not expected_left and not values_left:
+            return True  # expectations and values matched one-to-one
+        if not expected_left or not values_left:
+            return False  # expectations or values left but nothing to match with
+
+        expected_head, expected_tail = expected_left[0], expected_left[1:]
+        return any(self.nested_match(expected_head, value) and
+                   self.__has_a_solution(expected_tail, i_removed(values_left, i))
+                   for i, value in enumerate(values_left))
 
     def _description(self) -> str:
         return repr(self.expected_values)
@@ -358,7 +368,7 @@ class First(Transformer):
         self.how_many = how_many
         self.matcher: Optional[Matchable] = None
 
-    def __call__(self, matcher: Matchable) -> _First:
+    def matches(self, matcher: Matchable) -> _First:
         """
         :param matcher: The :class:`Matcher` to apply on the extracted slice.
         """
@@ -400,7 +410,7 @@ class Last(Transformer):
     def __init__(self, how_many: int = 1):
         self.how_many = how_many
 
-    def __call__(self, matcher: Matchable) -> _Last:
+    def matches(self, matcher: Matchable) -> _Last:
         """
         :param matcher: The :class:`Matcher` to apply on the extracted slice.
         """
@@ -428,7 +438,7 @@ class _SliceTransformer(Transformer):
     def __init__(self, slice_: Union[int, slice]) -> None:
         self.slice: Union[int, slice] = slice_
 
-    def __call__(self, matcher: Matchable) -> _Slice:
+    def matches(self, matcher: Matchable) -> _Slice:
         """
         :param matcher: The :class:`Matcher` to apply on the extracted slice.
         """
